@@ -15,4 +15,9 @@ sub new { bless {}, shift }
 sub bar { return 'bar' }
 sub baz { return 'baz' }
 
+package t::Bar;
+sub new { bless {}, shift }
+sub foo { return 'foo' }
+sub baz { return 'baz' }
+
 1;
